#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_DIVROUND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_DIVROUND_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/scalar/divround.hpp>

#endif
